@@ -123,6 +123,18 @@ def attach_stitch_lua_scripts(redis_client):
                 expire_postfix=PROFILE_VALUE_EXPIRE_AT_POSTFIX
             ))
 
+    if not hasattr(redis_client, 'remove_stitch_keys_from_pool'):
+
+        redis_client.remove_stitch_keys_from_pool = redis_client.register_script(
+            LuaScripts.remove_stitch_keys_from_pool()
+        )
+
+    if not hasattr(redis_client, 'remove_user_ids_from_stitch'):
+
+        redis_client.remove_user_ids_from_stitch = redis_client.register_script(
+            LuaScripts.remove_user_ids_from_stitch()
+        )
+
     return redis_client
 
 def getProfileClass(
