@@ -26,8 +26,8 @@ DEFAULT_FAST_CLEAN_THRESHOLD = 3
 DEFAULT_CLEAN_QUEUE_TTL = 24 * 60 * 60
 DEFAULT_MAX_STITCH_KEYS = 50
 
-def set_data_type_properties(cls):
 
+def set_data_type_properties(cls):
     cls.data_types = {
         prop.py_key: (prop.js_key, prop) for prop in
         [obj for name, obj in inspect.getmembers(sys.modules[profile_properties.__name__])
@@ -44,7 +44,6 @@ def set_data_type_properties(cls):
 
 @set_data_type_properties
 class Profile(object):
-
     db_lookup_fail_check_ttl = 24 * 60 * 60
     domain = DEFAULT_DOMAIN
     fast_clean_threshold = DEFAULT_FAST_CLEAN_THRESHOLD
@@ -143,7 +142,7 @@ class Profile(object):
         if isinstance(other, int) and other == 0:
             return self
 
-        assert self.__class__ == other.__class__, 'Cannot add {} to {}'\
+        assert self.__class__ == other.__class__, 'Cannot add {} to {}' \
             .format(self.__class__.__name__, other.__class__.__name__)
 
         assert self.domain == other.domain, 'Cannot add profiles for different domains'
@@ -282,7 +281,7 @@ class Profile(object):
     def set_db_lookup_fail(cls, user_id):
 
         cls.redis_client.set(cls._user_not_found_in_db_key(user_id=user_id), value='1',
-                                        nx=True, ex=cls.db_lookup_fail_check_ttl)
+                             nx=True, ex=cls.db_lookup_fail_check_ttl)
 
     def store_in_db(self, data=None):
 
@@ -392,23 +391,32 @@ class Profile(object):
                      force_db_lookup=False):
 
         profile_pool_keys = [cls._profile_pool_key(user_id) for user_id in user_ids]
-        data = cls.redis_client.get_stitched_user_profile(keys=[], args=[json.dumps(profile_pool_keys), time.timestamp()])
+        data = cls.redis_client.get_stitched_user_profile(keys=[],
+                                                          args=[json.dumps(profile_pool_keys), time.timestamp()])
         # a dictionary with profile_pool_key as key and corresponding (profile_key - profile) dict as value
         data_dict = {k.decode(): {pk.decode(): pr for pk, pr in dict(zip(v[::2], v[1::2])).items()} if v else None
                      for k, v in dict(zip(data[::2], data[1::2])).items()}
         # incomplete users are users that have profile keys in their profile pool, whose profile is not present
-        incomplete_users = {cls._user_id_from_profile_pool_key(k): v or {} for k, v in data_dict.items() if not v or any(not bool(x) for x in v.values())}
-        complete_users = {u:p for u,p in {cls._user_id_from_profile_pool_key(k): v for k, v in data_dict.items()}.items() if not u in incomplete_users}
-
+        incomplete_users = {cls._user_id_from_profile_pool_key(k): v or {} for k, v in data_dict.items() if
+                            not v or any(not bool(x) for x in v.values())}
+        complete_users = {u: p for u, p in
+                          {cls._user_id_from_profile_pool_key(k): v for k, v in data_dict.items()}.items() if
+                          not u in incomplete_users}
         complete_profiles = [p for p in [cls.from_redis_data(data=d,
                                                              key=key,
-                                                             user_id=user_id) for user_id, user_data in complete_users.items() for key, d in user_data.items()] if not p is None]
+                                                             user_id=user_id) for user_id, user_data in
+                                         complete_users.items() for key, d in user_data.items()] if not p is None]
 
+        incomplete_users = {user_id: {key: cls.from_redis_data(data=d,
+                                                               key=key,
+                                                               user_id=user_id) for key, d in user_data.items() if d}
+                            for user_id, user_data in incomplete_users.items()}
         missing_users = []
 
         if fallback_to_db_lookup or force_db_lookup:
 
             from_db = cls.from_database_by_user_ids(incomplete_users.keys())
+
             complemented_profiles = []
             for user_id, profiles_for_user in incomplete_users.items():
                 from_db_for_user = from_db.get(user_id, [])
@@ -416,20 +424,18 @@ class Profile(object):
                     if len(from_db_for_user) == 0:
                         missing_users.append(user_id)
                     else:
-                        complemented_profiles.extend([cls.from_redis_data(profile.data,
-                                                                          key=profile.key,
-                                                                          user_id=user_id) for profile in from_db_for_user])
+                        complemented_profiles.extend(from_db_for_user)
                 else:
                     for profile in from_db_for_user:
-                        if not profile.key in profiles_for_user:
-                            profiles_for_user[profile.key] = profile.data
-                complemented_profiles.extend(cls.from_redis_data(data=d,
-                                                                 key=key,
-                                                                 user_id=user_id) for key,d in profiles_for_user.items())
+                        if not profile.profile_key in profiles_for_user:
+                            complemented_profiles.append(profile)
+
+                    complemented_profiles.extend(profiles_for_user.values())
         else:
             complemented_profiles = [cls.from_redis_data(data=d,
                                                          key=key,
-                                                         user_id=user_id) for user_id, user_data in incomplete_users.items() for key, d in user_data.items()]
+                                                         user_id=user_id) for user_id, user_data in
+                                     incomplete_users.items() for key, d in user_data.items()]
 
         complemented_profiles = [p for p in complemented_profiles if not p is None]
 
@@ -493,7 +499,7 @@ class Profile(object):
             user_id = str(profile_model.user_id)
             profile = cls.from_flat_data(data=json.loads(profile_model.data),
                                          user_id=user_id)
-            profile.profile_id = profile_model.profile_id
+            profile.profile_id = str(profile_model.profile_id)
             result[user_id] = result.get(user_id, []) + [profile]
 
         failed_users = [u for u in user_ids if not u in result]
@@ -508,7 +514,7 @@ class Profile(object):
                       user_id):
         try:
             profile_model = cls.usable_django_model().objects.get(profile_id=cls.profile_id_from_key(key),
-                                                             user_id=user_id)
+                                                                  user_id=user_id)
         except cls.django_profile_model.DoesNotExist:
             return None
         return cls.from_flat_data(data=json.loads(profile_model.data),
@@ -518,7 +524,6 @@ class Profile(object):
     def from_flat_data(cls,
                        data,
                        user_id):
-
         names = {'_'.join(n.split('_')[:-1]) for n in data if not n in ('_updated', '_created', '_user_hash')}
 
         properties = {}
@@ -550,7 +555,6 @@ class Profile(object):
                                                            created=created,
                                                            expire_at=expire_at)
             properties[data_type] = props
-
         _updated = cls.timestamp_to_datetime(data['_updated'])
         _created = cls.timestamp_to_datetime(data['_created'])
 
@@ -732,7 +736,7 @@ class Profile(object):
         profile_ids = [cls.profile_id_from_key(key) for key in keys]
 
         profile_models = list(cls.usable_django_model().objects.filter(profile_id__in=profile_ids, user_id=user_id))
-        profiles = {cls._profile_key(profile_model.profile_id):
+        profiles = {cls._profile_key(str(profile_model.profile_id)):
                         cls.from_flat_data(data=json.loads(profile_model.data),
                                            user_id=user_id)
                     for profile_model in profile_models}
