@@ -336,7 +336,7 @@ class Stitch(object):
                 pipe.zrem(self.stitch_pool_key(user_id=user_id), self.key)
         pipe.execute()
         self.user_ids = self.user_ids - set(user_ids)
-        self.user_ids_with_ts = {k: v for k, v in self.user_ids_with_ts if not k in user_ids}
+        self.user_ids_with_ts = {k: v for k, v in self.user_ids_with_ts.items() if not k in user_ids}
 
     def set_recent_db_check(self):
 
@@ -375,7 +375,7 @@ class Stitch(object):
         model = cls.usable_django_model()
         stitch_models = list(model.objects.filter(key__in=list(should_check_dict.keys())))
         for stitch_model in stitch_models:
-            should_check_dict[stitch_model.key] = should_check_dict[stitch_model.key].add_user_ids(
+            should_check_dict[stitch_model.key].add_user_ids(
                 [str(u) for u in stitch_model.user_ids],
                 [float(t) for t in stitch_model.timestamps]
             )
